import { GraphQLClient } from 'graphql-request';
import * as Dom from 'graphql-request/dist/types.dom';
import gql from 'graphql-tag';

export const BloodPressureQueryDocument = gql`
    query BloodPressureQuery {
  bloodPressure {
    data {
      history {
        events {
          a24HourAverage {
            data {
              itemTree {
                items {
                  systolic {
                    value {
                      dvQuantity {
                        property {
                          terminologyId
                          codeString
                          terminologyVersion
                        }
                        magnitude
                        units
                        precision
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
    `;

export type SdkFunctionWrapper = <T>(action: (requestHeaders?:Record<string, string>) => Promise<T>, operationName: string) => Promise<T>;


const defaultWrapper: SdkFunctionWrapper = (action, _operationName) => action();

export function getSdk(client: GraphQLClient, withWrapper: SdkFunctionWrapper = defaultWrapper) {
  return {
    BloodPressureQuery(variables?: BloodPressureQueryQueryVariables, requestHeaders?: Dom.RequestInit["headers"]): Promise<BloodPressureQueryQuery> {
      return withWrapper((wrappedRequestHeaders) => client.request<BloodPressureQueryQuery>(BloodPressureQueryDocument, variables, {...requestHeaders, ...wrappedRequestHeaders}), 'BloodPressureQuery');
    }
  };
}
export type Sdk = ReturnType<typeof getSdk>;