import { gql } from '@apollo/client';
import * as Apollo from '@apollo/client';
const defaultOptions =  {}

export const BloodPressureQueryDocument = gql`
    query BloodPressureQuery {
  bloodPressure {
    data {
      history {
        events {
          a24HourAverage {
            data {
              itemTree {
                items {
                  systolic {
                    value {
                      dvQuantity {
                        property {
                          terminologyId
                          codeString
                          terminologyVersion
                        }
                        magnitude
                        units
                        precision
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
    `;

/**
 * __useBloodPressureQueryQuery__
 *
 * To run a query within a React component, call `useBloodPressureQueryQuery` and pass it any options that fit your needs.
 * When your component renders, `useBloodPressureQueryQuery` returns an object from Apollo Client that contains loading, error, and data properties
 * you can use to render your UI.
 *
 * @param baseOptions options that will be passed into the query, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options;
 *
 * @example
 * const { data, loading, error } = useBloodPressureQueryQuery({
 *   variables: {
 *   },
 * });
 */
export function useBloodPressureQueryQuery(baseOptions?: Apollo.QueryHookOptions<BloodPressureQueryQuery, BloodPressureQueryQueryVariables>) {
        const options = {...defaultOptions, ...baseOptions}
        return Apollo.useQuery<BloodPressureQueryQuery, BloodPressureQueryQueryVariables>(BloodPressureQueryDocument, options);
      }
export function useBloodPressureQueryLazyQuery(baseOptions?: Apollo.LazyQueryHookOptions<BloodPressureQueryQuery, BloodPressureQueryQueryVariables>) {
          const options = {...defaultOptions, ...baseOptions}
          return Apollo.useLazyQuery<BloodPressureQueryQuery, BloodPressureQueryQueryVariables>(BloodPressureQueryDocument, options);
        }
export type BloodPressureQueryQueryHookResult = ReturnType<typeof useBloodPressureQueryQuery>;
export type BloodPressureQueryLazyQueryHookResult = ReturnType<typeof useBloodPressureQueryLazyQuery>;
export type BloodPressureQueryQueryResult = Apollo.QueryResult<BloodPressureQueryQuery, BloodPressureQueryQueryVariables>;